# Nomodeco.py a normal mode decomposition tool


Nomodeco.py enables the automatic determination of an optimal internal coordinate set for a given molecular structure. Using the atomic coordinates of the given molecule Nomodeco.py constructs all possible primitive internal coordinates.

## Publication for further information:
Kemal Oenen, Dennis F. Dinu, Klaus R. Liedl; Determining internal coordinate sets for optimal representation of molecular vibration. J. Chem. Phys. 7 January 2024; 160 (1): 014104. https://doi.org/10.1063/5.0180657

